
.. py:currentmodule:: pythreejs

WebGLIndexedBufferRenderer
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: WebGLIndexedBufferRenderer()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/renderers/webgl/WebGLIndexedBufferRenderer


